﻿var workflowHistory;

$(function () {
    $('.wfIcon').live('click', function () {
        var docId = $(this).data('docid');
        if (docId) {
            showWorkflowHistory(docId);
        }
    });
});

function showWorkflowHistory(docId) {
    if (!docId) {
        var selRowId = $("#grid").jqGrid('getGridParam', 'selrow');
        docId = $("#grid").getRowData(selRowId).Id;
    }

    var params = $.param( {docId: docId});

    $.get('Home/GetDocumentWorkflowNames', params, function (data) {
        $('#workflowHistoryDialog').html(data);

        $('#WfTaskDecisionPanel').hide();
        $('#WfReasignDecisionPanel').hide();

        $.ajax({
            type: "GET",
            url: "Home/GetDocumentHistory",
            contentType: "application/x-www-form-urlencoded; charset=utf-8",
            data: params,
            success: function (historyData) {
                workflowHistory = historyData;
                $('#workflowHistoryDialog .steps').tabs({
                    select: function (event, ui) {
                        showWorkflow(ui.index);
                    }
                });
                $('#wfActionGrid').jqGrid({
                    datatype: "local",
                    viewrecords: true,
                    emptyrecords: 'No actions found!',
                    sortname: 'Date',
                    sortorder: "asc",
                    colNames: wfColumnNames,
                    colModel: [
                        { name: 'StepNumber', index: 'StepNumber', formatter: "int", align: "right", sorttype: 'int' },
                        { name: 'Type', index: 'Type' },
                        { name: 'StepName', index: 'StepName' },
                        { name: 'Description', index: 'Description' },
                        { name: 'DateTimeString', index: 'DateTimeString' },
                        { name: 'Id', index: 'Id', hidden: 'true' }
                        ],
                    onSelectRow: function (rowid) {
                        var rowData = $("#wfActionGrid").getRowData(rowid);
                        var taskId = rowData.Id;

                        var gridData = $("#wfActionGrid").jqGrid('getGridParam', 'data');

                        $.grep(gridData, function (history) {
                            if (history.Id == taskId) {
                                showWorflowDecision(history);
                            }
                        });
                    }
                });

                var closeButtonText = historyData.CloseButtonText;
                var buttonOpts = {};
                buttonOpts[closeButtonText] = function () {
                    $(this).dialog("close");
                };

                $('#workflowHistoryDialog').dialog({
                    width: 750,
                    height: 630,
                    modal: true,
                    resizable: false,
                    buttons: buttonOpts,
                    title: historyData.WorkflowHistoryDialogTitle
                });

                //$('#wfActionGrid').setGridWidth(724, false);

                showWorkflow(0);

                $('#wfActionGrid').setGridWidth(715);
                $('#wfActionGrid').setGridHeight("215");
            },
            error: function () {
                workflowHistory = null;
            }
        });
    }, 'html');
    
}

function showWorkflow(index) {
    if (!workflowHistory) {
        return;
    }

    $('#WfTaskDecisionPanel').hide();
    $('#WfReasignDecisionPanel').hide();
    $('#WfNoDecisionPanel').show();

    var workflow = workflowHistory.Workflows[index];
    fillLabel($('#WfNameLabel'),workflow.WfName);
    fillLabel($('#WfVersionLabel'),workflow.WfVersion);
    fillLabel($('#WfStartDateLabel'),workflow.StartDateString);
    fillLabel($('#WfEndDateLabel'),workflow.EndDateString);

    $('#wfActionGrid').jqGrid('clearGridData');
    $('#wfActionGrid').jqGrid('setGridParam', 
        {
            datatype: 'local',
            data: workflow.Histories 
        });
    $('#wfActionGrid').trigger("reloadGrid");
}

function showWorflowDecision(taskHistory) {
    if (taskHistory.TaskDecision) {
        $('#WfTaskDecisionPanel').show();
        $('#WfReasignDecisionPanel').hide();
        $('#WfNoDecisionPanel').hide();

        var decision = taskHistory.TaskDecision;

        fillLabel($('#WfDecisionNameLabel'), decision.Name);
        fillTooltip($('#WfDecisionNameLabel'), decision.Description);

        var decisionsDiv = $('<div></div>');
        var decisionList = $('<ol></ol>');
        decisionsDiv.append(decisionList);

        $.each(decision.Fields, function (index, field) {
            var decisionLi = $('<li></li>');
            decisionList.append(decisionLi);
            var title = $('<span class="key"></span>').text(field.Name);
            fillTooltip(title, field.Description);
            decisionLi.append(title);
            decisionLi.append(createLabelOrSelect(field.DisplayValue, field.ValuesList));
        });

        $('#WfTaskDecisionPanel').html(decisionsDiv.html());        
    }
    else if (taskHistory.ReasignDecision) {
        $('#WfTaskDecisionPanel').hide();
        $('#WfReasignDecisionPanel').show();
        $('#WfNoDecisionPanel').hide();

        var d = taskHistory.ReasignDecision;

        fillLabel($('#ResignDecisionBy'), d.Entities);
        fillLabel($('#ResignDecisionMessage'), d.Body);
        fillLabel($('#ReasignDecisionSubject'), d.Subject);
        fillLabel($('#ReasignDecisionMailSent'), d.MailSentString);

        if (d.NewRoles && d.NewRoles.length > 0) {
            $('#ReasignNewRolesGroup').show();
            $('#ReasignNewRolesDiv').html(createLabelOrSelect(d.NewRoles, d.NewRolesList));
        }
        else {
            $('#ReasignNewRolesGroup').hide();
        }

        if (d.NewUsers && d.NewUsers.length > 0) {
            $('#ReasignNewUsersGroup').show();
            //$('#ReasignNewUsersGroup').append(createLabelOrSelect(d.NewUsers, d.NewUsersList));
            $('#ReasignNewUsersDiv').html(createLabelOrSelect(d.NewUsers, d.NewUsersList));
        }
        else {
            $('#ReasignNewUsersGroup').hide();
        }

        if (d.NewSubstRules && d.NewSubstRules.length > 0) {
            $('#ReasignNewSubstitutionGroup').show();
            $('#ReasignNewSubstitutionDiv').html(createLabelOrSelect(d.NewSubstRules, d.NewSubstRulesList));
        }
        else {
            $('#ReasignNewSubstitutionGroup').hide();
        }
    }
    else {
        $('#WfTaskDecisionPanel').hide();
        $('#WfReasignDecisionPanel').hide();        
        $('#WfNoDecisionPanel').show();
    }

    var button = $('<button class="toggle btn" type"button"><i class="icon-white icon-chevron-down"></i></button>');
    $("button.toggle").click(function () {
        var valueOption = $(this).parent(".value-option");

        var toggleButton = $(this);
        toggleButton.toggleClass('active');

        var optionsList = toggleButton.siblings(".list-options");

        $('i', toggleButton).toggleClass('icon-chevron-down').toggleClass('icon-chevron-up');
        optionsList.slideToggle('slow', function () { });

        var values = toggleButton.siblings("div");
        values.slideToggle('slow', function () { });
    });
}

function fillLabel(label,str) {
    if (str) {
        label.text(str);
    }
    else {
        label.text('');
    }
}

function fillTooltip(label, str) {
    if (str) {
        label.attr("title", str);
        label.addClass("tooltip");
    }
    else {
        label.attr("title", "");
        label.removeClass("tooltip");
    }
}

function createLabelOrSelect(str,list){
    if( !list || list.length == 0 ){
        //just label
        var label = $('<span class="value"></span>');
        if( str ){
            label.text(str);
        }
        return label;
    }
    else if( list.length == 1 )
    {
        var label = $('<span class="value"></span>');
        if( list[0] ){
            label.text(list[0]);
        }
        return label;
    }
    else {

        var divHost = $('<div></div>');
        // drop down with all the values
        var optionsList = $('<ul class="list-options"></ul>')

        if (str) {
            var value = $('<div class="value-option"></div>');
            var button = $('<button class="toggle btn" type"button"><i class="icon-white icon-chevron-down"></i></button>');
            
            value.append(button);
            value.append($('<div></div>').text(str));
            
            $.each(list, function (index, valueItem) {
                if (valueItem) {
                    optionsList.append($('<li class="option"></li>').text(valueItem));
                }
            });

            value.append(optionsList);

            divHost.append(value);
        }
        
        return divHost;
    }
}